<?php

namespace Hospital\Econsultation\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Hospital\Econsultation\Http\Requests\EconsultationRequest;
use Hospital\Econsultation\Interfaces\EconsultationRepositoryInterface;
use Hospital\Econsultation\Models\Econsultation;

/**
 * Resource controller class for econsultation.
 */
class EconsultationResourceController extends BaseController
{

    /**
     * Initialize econsultation resource controller.
     *
     * @param type EconsultationRepositoryInterface $econsultation
     *
     * @return null
     */
    public function __construct(EconsultationRepositoryInterface $econsultation)
    {
        parent::__construct();
        $this->repository = $econsultation;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Hospital\Econsultation\Repositories\Criteria\EconsultationResourceCriteria::class);
    }

    /**
     * Display a list of econsultation.
     *
     * @return Response
     */
    public function index(EconsultationRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Hospital\Econsultation\Repositories\Presenter\EconsultationPresenter::class)
                ->$function();
        }

        $econsultations = $this->repository->paginate();

        return $this->response->title(trans('econsultation::econsultation.names'))
            ->view('econsultation::econsultation.index', true)
            ->data(compact('econsultations'))
            ->output();
    }

    /**
     * Display econsultation.
     *
     * @param Request $request
     * @param Model   $econsultation
     *
     * @return Response
     */
    public function show(EconsultationRequest $request, Econsultation $econsultation)
    {

        if ($econsultation->exists) {
            $view = 'econsultation::econsultation.show';
        } else {
            $view = 'econsultation::econsultation.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('econsultation::econsultation.name'))
            ->data(compact('econsultation'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new econsultation.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(EconsultationRequest $request)
    {

        $econsultation = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('econsultation::econsultation.name')) 
            ->view('econsultation::econsultation.create', true) 
            ->data(compact('econsultation'))
            ->output();
    }

    /**
     * Create new econsultation.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(EconsultationRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $econsultation                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('econsultation::econsultation.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('econsultation/econsultation/' . $econsultation->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/econsultation/econsultation'))
                ->redirect();
        }

    }

    /**
     * Show econsultation for editing.
     *
     * @param Request $request
     * @param Model   $econsultation
     *
     * @return Response
     */
    public function edit(EconsultationRequest $request, Econsultation $econsultation)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('econsultation::econsultation.name'))
            ->view('econsultation::econsultation.edit', true)
            ->data(compact('econsultation'))
            ->output();
    }

    /**
     * Update the econsultation.
     *
     * @param Request $request
     * @param Model   $econsultation
     *
     * @return Response
     */
    public function update(EconsultationRequest $request, Econsultation $econsultation)
    {
        try {
            $attributes = $request->all();

            $econsultation->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('econsultation::econsultation.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('econsultation/econsultation/' . $econsultation->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('econsultation/econsultation/' . $econsultation->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the econsultation.
     *
     * @param Model   $econsultation
     *
     * @return Response
     */
    public function destroy(EconsultationRequest $request, Econsultation $econsultation)
    {
        try {

            $econsultation->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('econsultation::econsultation.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('econsultation/econsultation/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('econsultation/econsultation/' . $econsultation->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple econsultation.
     *
     * @param Model   $econsultation
     *
     * @return Response
     */
    public function delete(EconsultationRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('econsultation::econsultation.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('econsultation/econsultation'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/econsultation/econsultation'))
                ->redirect();
        }

    }

    /**
     * Restore deleted econsultations.
     *
     * @param Model   $econsultation
     *
     * @return Response
     */
    public function restore(EconsultationRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('econsultation::econsultation.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/econsultation/econsultation'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/econsultation/econsultation/'))
                ->redirect();
        }

    }

}
